Name:           i3
Version:        4.23
Release:        1%{?dist}
Epoch:          1000
Summary:        Improved tiling window manager
License:        BSD
URL:            https://i3wm.org
Source0:        %{URL}/downloads/%{name}-%{version}.tar.xz
Source1:        %{name}-logo.svg
Patch0:         0001-Show-qubes-domain-in-configurable-colored-borders.patch

BuildRequires:  gcc
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  meson >= 0.45.0


# from configure.ac and DEPENDS (mostly versions)
BuildRequires:  pkgconfig >= 0.25
# no pkg-config for libev
BuildRequires:  libev-devel >= 4.0
BuildRequires:  pkgconfig(libstartup-notification-1.0)
BuildRequires:  pkgconfig(xcb) >= 1.1.93
BuildRequires:  pkgconfig(xcb-xkb)
BuildRequires:  pkgconfig(xcb-xinerama)
BuildRequires:  pkgconfig(xcb-randr)
BuildRequires:  pkgconfig(xcb-shape)
BuildRequires:  pkgconfig(xcb-event)
BuildRequires:  pkgconfig(xcb-util)
BuildRequires:  pkgconfig(xcb-cursor)
BuildRequires:  pkgconfig(xcb-keysyms)
BuildRequires:  pkgconfig(xcb-icccm)
BuildRequires:  pkgconfig(xcb-xrm)
BuildRequires:  pkgconfig(xkbcommon) >= 0.4.0
BuildRequires:  pkgconfig(xkbcommon-x11) >= 0.4.0
BuildRequires:  pkgconfig(yajl) >= 2.0.1
# For some reson, using pkgconfig(libpcre2-8) fails
BuildRequires:  pcre2-devel
BuildRequires:  pkgconfig(cairo) >= 1.14.4
BuildRequires:  pkgconfig(pangocairo) >= 1.30.0
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
# man pages
BuildRequires:  asciidoc >= 8.3.0
BuildRequires:  xmlto >= 0.0.23

# TODO: Testsuites
BuildRequires:  perl(ExtUtils::MakeMaker)
#BuildRequires:  perl(strict)
#BuildRequires:  perl(warnings)
#BuildRequires:  perl(Pod::Usage)
#BuildRequires:  perl(Cwd)
#BuildRequires:  perl(File::Temp)
#BuildRequires:  perl(Getopt::Long)
#BuildRequires:  perl(POSIX)
#BuildRequires:  perl(TAP::Harness)
#BuildRequires:  perl(TAP::Parser)
#BuildRequires:  perl(TAP::Parser::Aggregator)
#BuildRequires:  perl(Time::HiRes)
#BuildRequires:  perl(IO::Handle)
#BuildRequires:  perl(AnyEvent::Util)
#BuildRequires:  perl(AnyEvent::Handle)
BuildRequires:  perl(AnyEvent::I3)
#BuildRequires:  perl(X11::XCB::Connection)
#BuildRequires:  perl(Carp)

BuildRequires:  perl-generators
BuildRequires:  perl(Pod::Simple)
%ifnarch s390 s390x
BuildRequires:  xorg-x11-drv-dummy
%endif

Requires: qubes-desktop-linux-common

Requires:       perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%{!?rhel:Recommends:     rxvt-unicode}
%{!?rhel:Recommends:     xorg-x11-apps}
Requires:       xorg-x11-fonts-misc
# for i3-save-tree
Requires:       perl(AnyEvent::I3) >= 0.12

%if 0%{?rhel} != 7
Recommends:     pulseaudio-utils
Recommends:     dmenu
Recommends:     i3status
Recommends:     i3lock
%endif

%description
Key features of i3 are correct implementation of XrandR, horizontal and vertical
columns (think of a table) in tiling. Also, special focus is on writing clean,
readable and well documented code. i3 uses xcb for asynchronous communication
with X11, and has several measures to be very fast.

Please be aware that i3 is primarily targeted at advanced users and developers.

%package        doc
Summary:        Documentation for %{name}
BuildArch:      noarch
Requires:       %{name} = %{epoch}:%{version}-%{release}

%description    doc
Asciidoc generated documentation for %{name}.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{epoch}:%{version}-%{release}

%description    devel
Header files for %{name}.

%package        devel-doc
Summary:        Documentation for the development files of %{name}
BuildRequires:  doxygen
BuildArch:      noarch
Requires:       %{name} = %{epoch}:%{version}-%{release}

%description    devel-doc
Doxygen generated documentations for %{name}.

%prep
%autosetup -p1

# Drop /usr/bin/env lines in those which will be installed to %%_bindir.
find . -maxdepth 1 -type f -name "i3*" -exec sed -i -e '1s;^#!/usr/bin/env perl;#!/usr/bin/perl;' {} + -print


%build

# See https://mesonbuild.com/Builtin-options.html for Meson built-in options
meson setup --prefix=/usr build && pushd build
meson compile

popd

echo "TODO: generate doxygen"
doxygen pseudo-doc.doxygen
mv pseudo-doc/html pseudo-doc/doxygen

%install
pushd build
DESTDIR=%{buildroot} meson install

popd

echo "Installing man-pages"
mkdir -p %{buildroot}%{_mandir}/man1/
install -Dpm0644 man/*.1 \
        %{buildroot}%{_mandir}/man1/

mkdir -p %{buildroot}%{_datadir}/pixmaps/
install -Dpm0644 %{SOURCE1} \
        %{buildroot}%{_datadir}/pixmaps/

%check
%ifnarch s390 s390x
# TODO: with xorg dummy to test the package.
# TODO: get remaining dependencies in
# make check
%endif

%files
%doc RELEASE-NOTES-%{version}
%license LICENSE
%{_bindir}/%{name}*
%dir %{_sysconfdir}/%{name}/
%config(noreplace) %{_sysconfdir}/%{name}/config
%config(noreplace) %{_sysconfdir}/%{name}/config.keycodes
%{_datadir}/xsessions/%{name}.desktop
%{_datadir}/xsessions/%{name}-with-shmlog.desktop
%{_mandir}/man*/%{name}*
%{_datadir}/pixmaps/%{name}-logo.svg
%{_datadir}/applications/%{name}.desktop
%exclude %{_docdir}/%{name}/

%files doc
%license LICENSE
%doc docs/*.{html,png}

%files devel
%license LICENSE
%{_includedir}/%{name}/

%files devel-doc
%license LICENSE
%doc pseudo-doc/doxygen/

%changelog
* Wed May 15 2024 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-desktop-linux-i3

* Wed May 15 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ee0b3e0
- version 4.23-1

* Mon Oct 30 2023 Minimalist <suspectindustrie@protonmail.com> - 04a1d53
- Update to upstream version 4.23

* Wed Jan 04 2023 anadahz <andz@torproject.org> - cc33ef1
- Fix Qubes i3 patch

* Wed Jan 04 2023 anadahz <andz@torproject.org> - d660532
- Update i3 to upstream release v4.22

* Sat Oct 22 2022 Martin Holst Swende <martin@swende.se> - c6ee3a9
- add missing pcre2-devel dep requirement

* Fri Oct 21 2022 Martin Holst Swende <martin@swende.se> - 4b384af
- revert to , minor nitpicks

* Fri Oct 21 2022 Martin Holst Swende <martin@swende.se> - 8ea748e
- some work towards getting it packaged on debian

* Fri Oct 21 2022 Martin Holst Swende <martin@swende.se> - 6b9428a
- finalize

* Fri Oct 21 2022 Martin Holst Swende <martin@swende.se> - fcad0a1
- make the basic build+install work

* Fri Oct 21 2022 Martin Holst Swende <martin@swende.se> - 3c92429
- spec: define bindir, datadir for meson

* Fri Oct 21 2022 Martin Holst Swende <martin@swende.se> - 259c917
- some work on the installation task

* Thu Oct 20 2022 Martin Holst Swende <martin@swende.se> - 142f6a8
- more work on the spec

* Thu Oct 20 2022 Martin Holst Swende <martin@swende.se> - b96627d
- rm patches from spec

* Thu Oct 20 2022 Martin Holst Swende <martin@swende.se> - 60cb319
- remove patches

* Thu Oct 20 2022 Martin Holst Swende <martin@swende.se> - 0971196
- new patch

* Mon Oct 17 2022 anadahz <andz@torproject.org> - d158a11
- Fix tar command to extract xz files

* Mon Oct 17 2022 anadahz <andz@torproject.org> - 5da04f4
- Fix file name extenstion

* Mon Oct 17 2022 anadahz <andz@torproject.org> - eacd6f5
- Add previously removed hash file with a correct name

* Mon Oct 17 2022 anadahz <andz@torproject.org> - d30f065
- Fix hash file name

* Fri Oct 14 2022 anadahz <andz@torproject.org> - f3f17b1
- Bump i3 version to 4.21

* Sun Sep 11 2022 anadahz <andz@torproject.org> - 2054247
- Update i3 to 4.20.1, replace to xz files

* Mon May 09 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - fb15cfa
- .qubesbuilder: replace 'spec' by 'build'

* Mon Apr 18 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 1557a6e
- Add Qubes Builder v2 integration

* Fri Apr 15 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 1e4b6f7
- Drop Travis CI

* Tue Nov 09 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - eb3d9d6
- version 4.18.2-5

* Fri May 14 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - a9d3ee6
- Clean up Makefile

* Wed May 12 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - f4439d1
- Switch from wget to curl

* Wed Nov 25 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - c03501a
- spec: fix automake build error

* Wed Nov 25 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 298ad41
- Revert "gitlab-ci: allow reprobuild to fail for now"

* Wed Nov 25 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 475e76e
- gitlab-ci: allow reprobuild to fail for now

* Sun Nov 15 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 853b704
- Add .gitlab-ci.yml

* Sat Nov 14 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 0c1648f
- Improve reproducibility

* Wed Oct 21 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 43ed37d
- version 4.18.2-4

* Mon Oct 19 2020 Daniel Moerner <dmoerner@gmail.com]> - 6b1601a
- Add upstream patch to kick tray clients earlier (upstream #4159)

* Sat Sep 19 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ad072bc
- version 4.18.2-3

* Sat Aug 22 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 9892229
- Disable build for CentOS 7

* Tue Aug 11 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - ff43058
- debian: initial packaging from upstream

* Fri Aug 07 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 8a3291f
- Update travis

* Fri Aug 07 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8f4ee22
- version 4.18.2-2

* Wed Aug 05 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 9f3a1dc
- spec: don't fails with CentOS 7 due to older rpm

* Wed Aug 05 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 40d77ab
- Remove useless/missing deps

* Tue Aug 04 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 3cf4f3e
- Update to 4.18.2

* Mon May 04 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - f103464
- Cleanup repo and update README

* Wed Apr 15 2020 w1k1n9cc <git@malbolge.de> - 67b4144
- Wrong package name for pkgconfig in spec file

* Mon Apr 06 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - eb0aa08
- Update Makefile and version to i3-4.18

* Fri Jan 24 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5799e71
- version 4.17.1-2

* Sun Jan 19 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - f658f24
- travis: drop dom0 Fedora 25

* Sun Jan 19 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 26a40af
- spec: sync with upstream

* Sat Jan 11 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 86d1188
- travis: switch to dom0 Fedora 31

* Sat Oct 19 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 00befe6
- travis: switch to bionic

